# External Link Translation

This module enhances Drupal's multilingual capabilities by providing a straightforward means for translating external links. It introduces a custom content entity that enables content editors to define external link translations from within the admin UI. To apply translations, editors just need to copy the canonical link generated by the entity and paste it into menus, link fields, or any site component that accepts internal links. The module then transforms these paths into the appropriate external links, helping support a consistent navigation structure for users in different languages.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/external_link_translation).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/external_link_translation).

## Table of contents

- Requirements
- Installation
- Configuration
- Developing

## Requirements 

This module requires no modules outside of Drupal core.

## Installation

Install as you would normally install a contributed Drupal module. For further information, see [Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

1. Enable the module by navigating to **Administration > Extend**.
2. Make the *External link translation* entity translatable by going to **Administration > Configuration > Content language and translation**.
3. Users with the *Administer external link translations* permission can begin creating and managing external link translations under **Administration > Content > External Link Translations**.

## Developing

To assist with local development and testing, there is a Dockerfile that can be used. All module dependencies are included.

```shell
docker-compose up -d --build
```

### Enabling XDebug for Debugging

```shell
XDEBUG_MODE=debug docker-compose up
```

### Running Drupal PHPUnit Tests

```shell
docker-compose run drupal phpunit
```

### Running Drupal Code Quality Tests

```shell
docker-compose run drupal phpcs
```

### Running Drupal Code Beautifier and Fixer

```shell
docker-compose run drupal phpcbf
```
